/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef prmzah
#define prmzah

#include <QPixmap>
#include <QList>
#include <QMap>
#include <QSyntaxHighlighter>
#include <QTextDocument>

#include "Szines.h"
#include "con.h"

class jelzpn;

class jlszt 
<%
	public:
	int mrtdt;
	int jlzpnt;
	QString rabir;
%>;

class jlzlt 
<%
	public:
	QString irnyjl;
	QString adelk;
%>;

class prmza 
<%
	public:
		prmza(jelzpn *megkap, int lnmtat);
		jelzpn* kidlgz;

		QString mzgat;
		QString rabir;
		int kapni;
		QString hsztzk;

		QString kivalt;
		QString fladat;
		QString nybnvn;

		QPixmap fnqll;
		QPixmap dolog;

		int jlzpnt;
		double kapod;
		double mgzerz;
		double mrtdt;
		double adelk;

		int kket;

		QList<QString> prmz;

		int jo;
		int klsirz; 
		szn letsit;

		szn& akdaly();
		szn& felvnl();

		QString kitzjl;

		int mgmozt;
		int lep;
		QList<jlszt> jvsltz;
		QString mgmnkl;

		bool eler(const QString &);
%>;

#endif

